DistanceBuilder class
DistanceBuilder A length - a value with a unit that is a physical distance.
- Inheritance
-
- Object
- FhirBaseBuilder
- ElementBuilder
- DataTypeBuilder
- QuantityBuilder
- DistanceBuilder
- Implemented types
Constructors
-
DistanceBuilder({FhirStringBuilder? id, List<
FhirExtensionBuilder> ? extension_, FhirDecimalBuilder? value, QuantityComparatorBuilder? comparator, FhirStringBuilder? unit, FhirUriBuilder? system, FhirCodeBuilder? code, bool? disallowExtensions = false, String? objectPath = 'DistanceBuilder'}) - Primary constructor for DistanceBuilder
- DistanceBuilder.empty()
-
An empty constructor for partial usage.
For Builder classes, no fields are required
factory
-
DistanceBuilder.fromJson(Map<
String, dynamic> json) -
Factory constructor that accepts Map<String, dynamic> as an argument
factory
- DistanceBuilder.fromJsonString(String source)
-
Factory constructor for
DistanceBuilder
that takes in a String
Convenience method to avoid the json Encoding/Decoding normally required
to get data from a String
factory
- DistanceBuilder.fromYaml(dynamic yaml)
-
Deserialize DistanceBuilder
from a String or
YamlMapobjectfactory
Properties
- annotations ↔ List?
-
List of annotations for additional, non-core information
getter/setter pairinherited
- code ↔ FhirCodeBuilder?
-
code
A computer processable form of the unit in some unit representation
system.
getter/setter pairinherited
- comparator ↔ QuantityComparatorBuilder?
-
comparator
How the value should be understood and represented - whether the actual
value is greater or less than the stated value due to measurement
issues; e.g. if the comparator is "<" , then the real value is < stated
value.
getter/setter pairinherited
- disallowExtensions ↔ bool?
-
This is used in the FHIRPath engine to record that no extensions are
allowed for this item in the context in which it is used.
to do: enforce this....
getter/setter pairinherited
-
extension_
↔ List<
FhirExtensionBuilder> ? -
List of extensions for additional information
getter/setter pairinherited
- fhirType → String
-
Returns the FHIR type of the object.
no setteroverride
-
formatCommentsPost
↔ List<
String> ? -
List of comments to be added after the element.
getter/setter pairinherited
-
formatCommentsPre
↔ List<
String> ? -
List of comments to be added before the element.
getter/setter pairinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasId → bool
-
Getter for checking if the element has an id
no setterinherited
- hasPrimitiveValue → bool
-
Checks if the object has a primitive value.
no setterinherited
- id ↔ FhirStringBuilder?
-
Unique id for the element within a resource
getter/setter pairinherited
- isMetadataBased → bool
-
All
Elements are metadata basedno setterinherited - isPrimitive → bool
-
Checks if the object is primitive.
no setterinherited
- mappingId ↔ String?
-
Only for use in builders and only for mapping
getter/setter pairinherited
- objectPath ↔ String?
-
Path to the object in the FHIR tree.
getter/setter pairinherited
- primitiveValue → String?
-
Retrieves the primitive value of the object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- system ↔ FhirUriBuilder?
-
system
The identification of the system that provides the coded form of the
unit.
getter/setter pairinherited
- unit ↔ FhirStringBuilder?
-
unit
A human-readable form of the unit.
getter/setter pairinherited
-
userData
↔ Map<
String, dynamic> ? -
User data map for storing additional information.
getter/setter pairinherited
- value ↔ FhirDecimalBuilder?
-
value
The value of the measured amount. The value includes an implicit
precision in the presentation of the value.
getter/setter pairinherited
Methods
-
addAnnotation(
dynamic annotation) → FhirBaseBuilder -
Annotations Methods
inherited
-
addExtension(
FhirExtensionBuilder ext) → void -
Method to add an extension
inherited
-
build(
) → Distance -
Converts a DistanceBuilder
to
Distanceoverride -
clearUserData(
String name) → FhirBaseBuilder -
Clears user data for a given key.
inherited
-
clone(
) → DistanceBuilder -
Subclasses must implement the clone method.
override
-
compareDeepStrings(
String? s1, String? s2, bool allowNull) → bool -
Checks if the object is equal to another object.
inherited
-
copy(
) → ElementBuilder -
Method to copy the current element
inherited
-
copyWith(
{FhirStringBuilder? id, List< FhirExtensionBuilder> ? extension_, FhirDecimalBuilder? value, QuantityComparatorBuilder? comparator, FhirStringBuilder? unit, FhirUriBuilder? system, FhirCodeBuilder? code, Map<String, dynamic> ? userData, List<String> ? formatCommentsPre, List<String> ? formatCommentsPost, List? annotations, String? objectPath}) → DistanceBuilder -
Method to copy the current Element with modifications
override
-
createProperty(
String propertyName) → void -
Creates a new DistanceBuilder
with a chosen field set to an empty object.
override
-
equalsDeep(
FhirBaseBuilder? o) → bool -
Performs a deep comparison between two instances.
override
-
equalsShallow(
ElementBuilder other) → bool -
Method to compare shallow equality of two elements
inherited
-
getChildByName(
String name) → FhirBaseBuilder? -
Retrieves a single field value by its name.
override
-
getChildrenByName(
String fieldName, [bool checkValid = false]) → List< FhirBaseBuilder> -
Retrieves all matching child fields by name.
Optionally validates the name.
override
-
getExtensionFirstRep(
) → FhirExtensionBuilder -
Getter for the first extension
inherited
-
getExtensionsByUrl(
String url) → List< FhirExtensionBuilder> -
Getter for the first extension by url
inherited
-
getProperty(
String name) → dynamic -
Implementing the getProperty method
inherited
-
getUserData(
String name) → dynamic -
Gets user data for a given key.
inherited
-
getUserInt(
String name) → int -
Gets a user data value as an integer.
inherited
-
getUserString(
String name) → String? -
Gets a user data value as a string.
inherited
-
hasExtension(
) → bool -
Extension handling methods
inherited
-
hasExtensionByUrl(
String url) → bool -
Method to check if an extension exists by url
inherited
-
hasFormatComment(
) → bool -
Checks if there are format comments.
inherited
-
hasType(
List< String> names) → bool -
Checks if the object has a given type.
inherited
-
hasUserData(
String name) → bool -
Checks if the object has user data for a given key.
inherited
-
hasValues(
) → bool -
Checks if the object has values.
inherited
-
isAs<
T extends FhirBaseBuilder> () → T? -
Returns an Object cast as a Type if it is that type.
inherited
-
isEmpty(
) → bool -
Checks if the object is empty.
inherited
-
listChildrenNames(
) → List< String> -
Lists the JSON keys for the object.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
prettyPrint(
) → String -
Converts the object to a pretty JSON string.
inherited
-
removeAnnotations(
Type type) → FhirBaseBuilder -
Annotations Methods
inherited
-
removeExtension(
String url) → void -
Method to remove an extension by url
inherited
-
setChildByName(
String childName, dynamic child) → void -
Sets a property by name.
override
-
setChildrenByName(
Map< String, FhirBaseBuilder> children) → void -
Sets the properties of the object.
inherited
-
setProperty(
String name, dynamic value) → ElementBuilder -
Implementing the setProperty method
inherited
-
setUserData(
String name, dynamic value) → FhirBaseBuilder -
Sets user data for a given key.
inherited
-
toJson(
) → Map< String, dynamic> -
Converts a DistanceBuilder
to a Map<String, dynamic>
override
-
toJsonString(
) → String -
Converts the object to a JSON string.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
toYaml(
) → String -
Converts the object to a YAML string.
inherited
-
typeByElementName(
String fieldName) → List< String> -
Return the possible Dart types for the field named
fieldName. For polymorphic fields, multiple types are possible.override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited