GoalTargetBuilder class

GoalTargetBuilder Indicates what should be done by when.

Inheritance

Constructors

GoalTargetBuilder({FhirStringBuilder? id, List<FhirExtensionBuilder>? extension_, List<FhirExtensionBuilder>? modifierExtension, CodeableConceptBuilder? measure, DetailXGoalTargetBuilder? detailX, QuantityBuilder? detailQuantity, RangeBuilder? detailRange, CodeableConceptBuilder? detailCodeableConcept, FhirStringBuilder? detailString, FhirBooleanBuilder? detailBoolean, FhirIntegerBuilder? detailInteger, RatioBuilder? detailRatio, DueXGoalTargetBuilder? dueX, FhirDateBuilder? dueDate, FhirDurationBuilder? dueDuration, bool? disallowExtensions = false})
Primary constructor for GoalTargetBuilder
GoalTargetBuilder.empty()
An empty constructor for partial usage. For Builder classes, no fields are required
factory
GoalTargetBuilder.fromJson(Map<String, dynamic> json)
Factory constructor that accepts Map<String, dynamic> as an argument
factory
GoalTargetBuilder.fromJsonString(String source)
Factory constructor for GoalTargetBuilder that takes in a String Convenience method to avoid the json Encoding/Decoding normally required to get data from a String
factory
GoalTargetBuilder.fromYaml(dynamic yaml)
Deserialize GoalTargetBuilder from a String or YamlMap object
factory

Properties

annotations List?
List of annotations for additional, non-core information
getter/setter pairinherited
detailBoolean FhirBooleanBuilder?
Getter for detailBoolean as a FhirBooleanBuilder
no setter
detailCodeableConcept CodeableConceptBuilder?
Getter for detailCodeableConcept as a CodeableConceptBuilder
no setter
detailInteger FhirIntegerBuilder?
Getter for detailInteger as a FhirIntegerBuilder
no setter
detailQuantity QuantityBuilder?
Getter for detailQuantity as a QuantityBuilder
no setter
detailRange RangeBuilder?
Getter for detailRange as a RangeBuilder
no setter
detailRatio RatioBuilder?
Getter for detailRatio as a RatioBuilder
no setter
detailString FhirStringBuilder?
Getter for detailString as a FhirStringBuilder
no setter
detailX DetailXGoalTargetBuilder?
detailX The target value of the focus to be achieved to signify the fulfillment of the goal, e.g. 150 pounds, 7.0%. Either the high or low or both values of the range can be specified. When a low value is missing, it indicates that the goal is achieved at any focus value at or below the high value. Similarly, if the high value is missing, it indicates that the goal is achieved at any focus value at or above the low value.
getter/setter pair
disallowExtensions bool?
This is used in the FHIRPath engine to record that no extensions are allowed for this item in the context in which it is used. to do: enforce this....
getter/setter pairinherited
dueDate FhirDateBuilder?
Getter for dueDate as a FhirDateBuilder
no setter
dueDuration FhirDurationBuilder?
Getter for dueDuration as a FhirDurationBuilder
no setter
dueX DueXGoalTargetBuilder?
dueX Indicates either the date or the duration after start by which the goal should be met.
getter/setter pair
extension_ List<FhirExtensionBuilder>?
List of extensions for additional information
getter/setter pairinherited
fhirType String
Returns the FHIR type of the object.
no setteroverride
formatCommentsPost List<String>?
List of comments to be added after the element.
getter/setter pairinherited
formatCommentsPre List<String>?
List of comments to be added before the element.
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
hasId bool
Getter for checking if the element has an id
no setterinherited
hasPrimitiveValue bool
Checks if the object has a primitive value.
no setterinherited
id FhirStringBuilder?
Unique id for the element within a resource
getter/setter pairinherited
isMetadataBased bool
All Elements are metadata based
no setterinherited
isPrimitive bool
Checks if the object is primitive.
no setterinherited
mappingId String?
Only for use in builders and only for mapping
getter/setter pairinherited
measure CodeableConceptBuilder?
measure The parameter whose value is being tracked, e.g. body weight, blood pressure, or hemoglobin A1c level.
getter/setter pair
modifierExtension List<FhirExtensionBuilder>?
List of modifier extensions for additional, non-core information
getter/setter pairinherited
objectPath String?
Path to the object in the FHIR tree.
getter/setter pairinherited
primitiveValue String?
Retrieves the primitive value of the object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userData Map<String, dynamic>?
User data map for storing additional information.
getter/setter pairinherited

Methods

addAnnotation(dynamic annotation) FhirBaseBuilder
Annotations Methods
inherited
addExtension(FhirExtensionBuilder ext) → void
Method to add an extension
inherited
addModifierExtension(FhirExtensionBuilder ext) → void
Adds a modifier extension
inherited
build() → GoalTarget
Converts a GoalTargetBuilder to GoalTarget
override
clearUserData(String name) FhirBaseBuilder
Clears user data for a given key.
inherited
clone() GoalTargetBuilder
Subclasses must implement the clone method.
override
compareDeepStrings(String? s1, String? s2, bool allowNull) bool
Checks if the object is equal to another object.
inherited
copy() ElementBuilder
Method to copy the current element
inherited
copyWith({FhirStringBuilder? id, List<FhirExtensionBuilder>? extension_, List<FhirExtensionBuilder>? modifierExtension, CodeableConceptBuilder? measure, DetailXGoalTargetBuilder? detailX, DueXGoalTargetBuilder? dueX, QuantityBuilder? detailQuantity, RangeBuilder? detailRange, CodeableConceptBuilder? detailCodeableConcept, FhirStringBuilder? detailString, FhirBooleanBuilder? detailBoolean, FhirIntegerBuilder? detailInteger, RatioBuilder? detailRatio, FhirDateBuilder? dueDate, FhirDurationBuilder? dueDuration, Map<String, dynamic>? userData, List<String>? formatCommentsPre, List<String>? formatCommentsPost, List? annotations, String? objectPath}) GoalTargetBuilder
Method to copy the current Element with modifications
override
createProperty(String propertyName) → void
Creates a new GoalTargetBuilder with a chosen field set to an empty object.
override
equalsDeep(FhirBaseBuilder? o) bool
Performs a deep comparison between two instances.
override
equalsShallow(ElementBuilder other) bool
Method to compare shallow equality of two elements
inherited
getChildByName(String name) FhirBaseBuilder?
Retrieves a single field value by its name.
override
getChildrenByName(String fieldName, [bool checkValid = false]) List<FhirBaseBuilder>
Retrieves all matching child fields by name. Optionally validates the name.
override
getExtensionFirstRep() FhirExtensionBuilder
Getter for the first extension
inherited
getExtensionsByUrl(String url) List<FhirExtensionBuilder>
Getter for the first extension by url
inherited
getModifierExtensionFirstRep() FhirExtensionBuilder
Gets the first repetition of modifier extensions
inherited
getModifierExtensionsByUrl(String url) List<FhirExtensionBuilder>
Retrieves all modifier extensions by URL
inherited
getProperty(String name) → dynamic
Implementing the getProperty method
inherited
getUserData(String name) → dynamic
Gets user data for a given key.
inherited
getUserInt(String name) int
Gets a user data value as an integer.
inherited
getUserString(String name) String?
Gets a user data value as a string.
inherited
hasExtension() bool
Extension handling methods
inherited
hasExtensionByUrl(String url) bool
Method to check if an extension exists by url
inherited
hasFormatComment() bool
Checks if there are format comments.
inherited
hasModifierExtension() bool
Method to check if there are any modifier extensions
inherited
hasType(List<String> names) bool
Checks if the object has a given type.
inherited
hasUserData(String name) bool
Checks if the object has user data for a given key.
inherited
hasValues() bool
Checks if the object has values.
inherited
isAs<T extends FhirBaseBuilder>() → T?
Returns an Object cast as a Type if it is that type.
inherited
isEmpty() bool
Checks if the object is empty.
inherited
listChildrenNames() List<String>
Lists the JSON keys for the object.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
prettyPrint() String
Converts the object to a pretty JSON string.
inherited
removeAnnotations(Type type) FhirBaseBuilder
Annotations Methods
inherited
removeExtension(String url) → void
Method to remove an extension by url
inherited
removeModifierExtension(String url) → void
Removes modifier extensions by URL
inherited
setChildByName(String childName, dynamic child) → void
Sets a property by name.
override
setChildrenByName(Map<String, FhirBaseBuilder> children) → void
Sets the properties of the object.
inherited
setProperty(String name, dynamic value) ElementBuilder
Implementing the setProperty method
inherited
setUserData(String name, dynamic value) FhirBaseBuilder
Sets user data for a given key.
inherited
toJson() Map<String, dynamic>
Converts a GoalTargetBuilder to a Map<String, dynamic>
override
toJsonString() String
Converts the object to a JSON string.
inherited
toString() String
A string representation of this object.
inherited
toYaml() String
Converts the object to a YAML string.
inherited
typeByElementName(String fieldName) List<String>
Return the possible Dart types for the field named fieldName. For polymorphic fields, multiple types are possible.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited