ProductShelfLifeBuilder class

ProductShelfLifeBuilder The shelf-life and storage information for a medicinal product item or container can be described using this class.

Inheritance

Constructors

ProductShelfLifeBuilder({FhirStringBuilder? id, List<FhirExtensionBuilder>? extension_, List<FhirExtensionBuilder>? modifierExtension, IdentifierBuilder? identifier, CodeableConceptBuilder? type, QuantityBuilder? period, List<CodeableConceptBuilder>? specialPrecautionsForStorage, bool? disallowExtensions = false, String? objectPath = 'ProductShelfLifeBuilder'})
Primary constructor for ProductShelfLifeBuilder
ProductShelfLifeBuilder.empty()
An empty constructor for partial usage. For Builder classes, no fields are required
factory
ProductShelfLifeBuilder.fromJson(Map<String, dynamic> json)
Factory constructor that accepts Map<String, dynamic> as an argument
factory
ProductShelfLifeBuilder.fromJsonString(String source)
Factory constructor for ProductShelfLifeBuilder that takes in a String Convenience method to avoid the json Encoding/Decoding normally required to get data from a String
factory
ProductShelfLifeBuilder.fromYaml(dynamic yaml)
Deserialize ProductShelfLifeBuilder from a String or YamlMap object
factory

Properties

annotations List?
List of annotations for additional, non-core information
getter/setter pairinherited
disallowExtensions bool?
This is used in the FHIRPath engine to record that no extensions are allowed for this item in the context in which it is used. to do: enforce this....
getter/setter pairinherited
extension_ List<FhirExtensionBuilder>?
List of extensions for additional information
getter/setter pairinherited
fhirType String
Returns the FHIR type of the object.
no setteroverride
formatCommentsPost List<String>?
List of comments to be added after the element.
getter/setter pairinherited
formatCommentsPre List<String>?
List of comments to be added before the element.
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
hasId bool
Getter for checking if the element has an id
no setterinherited
hasPrimitiveValue bool
Checks if the object has a primitive value.
no setterinherited
id FhirStringBuilder?
Unique id for the element within a resource
getter/setter pairinherited
identifier IdentifierBuilder?
identifier Unique identifier for the packaged Medicinal Product.
getter/setter pair
isMetadataBased bool
All Elements are metadata based
no setterinherited
isPrimitive bool
Checks if the object is primitive.
no setterinherited
mappingId String?
Only for use in builders and only for mapping
getter/setter pairinherited
modifierExtension List<FhirExtensionBuilder>?
List of modifier extensions for additional, non-core information
getter/setter pairinherited
objectPath String?
Path to the object in the FHIR tree.
getter/setter pairinherited
period QuantityBuilder?
period The shelf life time period can be specified using a numerical value for the period of time and its unit of time measurement The unit of measurement shall be specified in accordance with ISO 11240 and the resulting terminology The symbol and the symbol identifier shall be used.
getter/setter pair
primitiveValue String?
Retrieves the primitive value of the object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
specialPrecautionsForStorage List<CodeableConceptBuilder>?
specialPrecautionsForStorage Special precautions for storage, if any, can be specified using an appropriate controlled vocabulary The controlled term and the controlled term identifier shall be specified.
getter/setter pair
type CodeableConceptBuilder?
type This describes the shelf life, taking into account various scenarios such as shelf life of the packaged Medicinal Product itself, shelf life after transformation where necessary and shelf life after the first opening of a bottle, etc. The shelf life type shall be specified using an appropriate controlled vocabulary The controlled term and the controlled term identifier shall be specified.
getter/setter pair
userData Map<String, dynamic>?
User data map for storing additional information.
getter/setter pairinherited

Methods

addAnnotation(dynamic annotation) FhirBaseBuilder
Annotations Methods
inherited
addExtension(FhirExtensionBuilder ext) → void
Method to add an extension
inherited
addModifierExtension(FhirExtensionBuilder ext) → void
Adds a modifier extension
inherited
build() → ProductShelfLife
Converts a ProductShelfLifeBuilder to ProductShelfLife
override
clearUserData(String name) FhirBaseBuilder
Clears user data for a given key.
inherited
clone() ProductShelfLifeBuilder
Subclasses must implement the clone method.
override
compareDeepStrings(String? s1, String? s2, bool allowNull) bool
Checks if the object is equal to another object.
inherited
copy() ElementBuilder
Method to copy the current element
inherited
copyWith({FhirStringBuilder? id, List<FhirExtensionBuilder>? extension_, List<FhirExtensionBuilder>? modifierExtension, IdentifierBuilder? identifier, CodeableConceptBuilder? type, QuantityBuilder? period, List<CodeableConceptBuilder>? specialPrecautionsForStorage, Map<String, dynamic>? userData, List<String>? formatCommentsPre, List<String>? formatCommentsPost, List? annotations, String? objectPath}) ProductShelfLifeBuilder
Method to copy the current Element with modifications
override
createProperty(String propertyName) → void
Creates a new ProductShelfLifeBuilder with a chosen field set to an empty object.
override
equalsDeep(FhirBaseBuilder? o) bool
Performs a deep comparison between two instances.
override
equalsShallow(ElementBuilder other) bool
Method to compare shallow equality of two elements
inherited
getChildByName(String name) FhirBaseBuilder?
Retrieves a single field value by its name.
override
getChildrenByName(String fieldName, [bool checkValid = false]) List<FhirBaseBuilder>
Retrieves all matching child fields by name. Optionally validates the name.
override
getExtensionFirstRep() FhirExtensionBuilder
Getter for the first extension
inherited
getExtensionsByUrl(String url) List<FhirExtensionBuilder>
Getter for the first extension by url
inherited
getModifierExtensionFirstRep() FhirExtensionBuilder
Gets the first repetition of modifier extensions
inherited
getModifierExtensionsByUrl(String url) List<FhirExtensionBuilder>
Retrieves all modifier extensions by URL
inherited
getProperty(String name) → dynamic
Implementing the getProperty method
inherited
getUserData(String name) → dynamic
Gets user data for a given key.
inherited
getUserInt(String name) int
Gets a user data value as an integer.
inherited
getUserString(String name) String?
Gets a user data value as a string.
inherited
hasExtension() bool
Extension handling methods
inherited
hasExtensionByUrl(String url) bool
Method to check if an extension exists by url
inherited
hasFormatComment() bool
Checks if there are format comments.
inherited
hasModifierExtension() bool
Method to check if there are any modifier extensions
inherited
hasType(List<String> names) bool
Checks if the object has a given type.
inherited
hasUserData(String name) bool
Checks if the object has user data for a given key.
inherited
hasValues() bool
Checks if the object has values.
inherited
isAs<T extends FhirBaseBuilder>() → T?
Returns an Object cast as a Type if it is that type.
inherited
isEmpty() bool
Checks if the object is empty.
inherited
listChildrenNames() List<String>
Lists the JSON keys for the object.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
prettyPrint() String
Converts the object to a pretty JSON string.
inherited
removeAnnotations(Type type) FhirBaseBuilder
Annotations Methods
inherited
removeExtension(String url) → void
Method to remove an extension by url
inherited
removeModifierExtension(String url) → void
Removes modifier extensions by URL
inherited
setChildByName(String childName, dynamic child) → void
Sets a property by name.
override
setChildrenByName(Map<String, FhirBaseBuilder> children) → void
Sets the properties of the object.
inherited
setProperty(String name, dynamic value) ElementBuilder
Implementing the setProperty method
inherited
setUserData(String name, dynamic value) FhirBaseBuilder
Sets user data for a given key.
inherited
toJson() Map<String, dynamic>
Converts a ProductShelfLifeBuilder to a Map<String, dynamic>
override
toJsonString() String
Converts the object to a JSON string.
inherited
toString() String
A string representation of this object.
inherited
toYaml() String
Converts the object to a YAML string.
inherited
typeByElementName(String fieldName) List<String>
Return the possible Dart types for the field named fieldName. For polymorphic fields, multiple types are possible.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited