DeviceMetricColorBuilder class
Describes the typical color of representation.
- Inheritance
-
- Object
- FhirBaseBuilder
- ElementBuilder
- DataTypeBuilder
- PrimitiveTypeBuilder
- FhirStringBuilder
- FhirCodeBuilder
- FhirCodeEnumBuilder
- DeviceMetricColorBuilder
Constructors
-
DeviceMetricColorBuilder(String? rawValue, {FhirUriBuilder? system, FhirStringBuilder? version, FhirStringBuilder? display, ElementBuilder? element, FhirStringBuilder? id, List<
FhirExtensionBuilder> ? extension_, bool? disallowExtensions, String objectPath = 'Code'}) -
Public factory if you want a fallback approach or custom creation.
factory
- DeviceMetricColorBuilder.empty()
-
Create empty DeviceMetricColorBuilder
with element only
factory
-
DeviceMetricColorBuilder.fromJson(Map<
String, dynamic> json) -
Factory constructor to create
DeviceMetricColorBuilder from JSON.
factory
Properties
- annotations ↔ List?
-
List of annotations for additional, non-core information
getter/setter pairinherited
-
codeUnits
→ List<
int> -
Returns the code units as a list of ints.
no setterinherited
- disallowExtensions ↔ bool?
-
This is used in the FHIRPath engine to record that no extensions are
allowed for this item in the context in which it is used.
to do: enforce this....
getter/setter pairinherited
- display → FhirStringBuilder?
-
display
A representation of the meaning of the code in the system, following
the rules of the system.
finalinherited
- element ↔ ElementBuilder?
-
Optional FHIR metadata element (usually carrying extensions).
getter/setter pairinherited
-
extension_
↔ List<
FhirExtensionBuilder> ? -
List of extensions for additional information
getter/setter pairinherited
- fhirType → String
-
Returns
"code".no setterinherited -
formatCommentsPost
↔ List<
String> ? -
List of comments to be added after the element.
getter/setter pairinherited
-
formatCommentsPre
↔ List<
String> ? -
List of comments to be added before the element.
getter/setter pairinherited
- hasElementBuilder → bool
-
Returns
trueif element is non-null.no setterinherited - hashCode → int
-
Hash code override.
no setterinherited
- hasId → bool
-
Getter for checking if the element has an id
no setterinherited
- hasPrimitiveValue → bool
-
Checks if the object has a primitive value.
no setterinherited
- hasValue → bool
-
Returns
trueif valueString is non-null.no setterinherited - hasValueAndElementBuilder → bool
-
Returns
trueif both valueString and element are non-null.no setterinherited - id ↔ FhirStringBuilder?
-
Unique id for the element within a resource
getter/setter pairinherited
- isEmptyString → bool
-
Checks if the string is empty.
no setterinherited
- isMetadataBased → bool
-
All
Elements are metadata basedno setterinherited - isNotEmpty → bool
-
Checks if the string is not empty.
no setterinherited
- isPrimitive → bool
-
Checks if the object is primitive.
no setterinherited
- length → int
-
The length of the string (or
0ifnull).no setterinherited - mappingId ↔ String?
-
Only for use in builders and only for mapping
getter/setter pairinherited
- objectPath ↔ String?
-
Path to the object in the FHIR tree.
getter/setter pairinherited
- primitiveValue → String?
-
The primitive value as a String.
no setterinherited
- runes → Runes?
-
Returns the runes (Unicode code points).
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringBased → bool
-
Returns
trueif the Type is considered string-based, otherwisefalseno setterinherited - system → FhirUriBuilder?
-
system
The identification of the code system that defines the meaning of the
symbol in the code.
finalinherited
-
userData
↔ Map<
String, dynamic> ? -
User data map for storing additional information.
getter/setter pairinherited
- valueEnum → DeviceMetricColorBuilderEnum?
-
An actual enum that can be used for DeviceMetricColorBuilder
final
- valueString ↔ String?
-
The primitive FHIR value as a String.
getter/setter pairinherited
- version → FhirStringBuilder?
-
version
The version of the code system which was used when choosing this code.
Note that a well-maintained code system does not need the version
reported, because the meaning of codes is consistent across versions.
However this cannot consistently be assured, and when the meaning is
not guaranteed to be consistent, the version SHOULD be exchanged.
finalinherited
Methods
-
addAnnotation(
dynamic annotation) → FhirBaseBuilder -
Annotations Methods
inherited
-
addExtension(
FhirExtensionBuilder ext) → void -
Method to add an extension
inherited
-
build(
) → FhirCode -
Method to convert the builder object to the original Element object
inherited
-
clearUserData(
String name) → FhirBaseBuilder -
Clears user data for a given key.
inherited
-
clone(
) → FhirCodeBuilder -
Creates a deep clone of this FhirStringBuilder.
inherited
-
codeUnitAt(
int index) → int? -
Returns the code unit at the specified
index.inherited -
compareDeepStrings(
String? s1, String? s2, bool allowNull) → bool -
Checks if the object is equal to another object.
inherited
-
contains(
Pattern pattern, [int startIndex = 0]) → bool -
Checks if
patternoccurs in the string.inherited -
copy(
) → ElementBuilder -
Method to copy the current element
inherited
-
copyWith(
{dynamic newValue, ElementBuilder? element, FhirStringBuilder? id, List< FhirExtensionBuilder> ? extension_, Map<String, dynamic> ? userData, List<String> ? formatCommentsPre, List<String> ? formatCommentsPost, List? annotations, bool? disallowExtensions, String? objectPath}) → FhirCodeBuilder -
Creates a modified copy with updated properties.
inherited
-
createProperty(
String propertyName) → FhirCodeBuilder -
Creates an empty property in the object (no-op).
inherited
-
endsWith(
String other) → bool -
Checks if the string ends with
other.inherited -
equals(
Object other) → bool -
Convenience method matching equalsDeep, except for checking userData.
inherited
-
equalsDeep(
FhirBaseBuilder? other) → bool -
Deep equality check.
inherited
-
equalsShallow(
FhirBaseBuilder other) → bool -
By default, shallow equality checks only valueString.
inherited
-
getChildByName(
String name) → FhirBaseBuilder? -
Retrieves a property by name, or if its a list that contains only one
element, returns that element.
inherited
-
getChildrenByName(
String name, [bool checkValid = false]) → List< FhirBaseBuilder> -
Retrieves the properties of the object.
inherited
-
getExtensionFirstRep(
) → FhirExtensionBuilder -
Getter for the first extension
inherited
-
getExtensionsByUrl(
String url) → List< FhirExtensionBuilder> -
Getter for the first extension by url
inherited
-
getProperty(
String name) → dynamic -
Implementing the getProperty method
inherited
-
getUserData(
String name) → dynamic -
Gets user data for a given key.
inherited
-
getUserInt(
String name) → int -
Gets a user data value as an integer.
inherited
-
getUserString(
String name) → String? -
Gets a user data value as a string.
inherited
-
hasExtension(
) → bool -
Extension handling methods
inherited
-
hasExtensionByUrl(
String url) → bool -
Method to check if an extension exists by url
inherited
-
hasFormatComment(
) → bool -
Checks if there are format comments.
inherited
-
hasType(
List< String> names) → bool -
Checks if the object has a given type.
inherited
-
hasUserData(
String name) → bool -
Checks if the object has user data for a given key.
inherited
-
hasValues(
) → bool -
Checks if the object has values.
inherited
-
indexOf(
Pattern pattern, [int start = 0]) → int -
Finds the first occurrence of
pattern.inherited -
isAs<
T extends FhirBaseBuilder> () → T? -
Returns an Object cast as a Type if it is that type.
inherited
-
isEmpty(
) → bool -
Checks if the object is empty.
inherited
-
lastIndexOf(
Pattern pattern, [int? start]) → int -
Finds the last occurrence of
pattern.inherited -
listChildrenNames(
) → List< String> -
Lists the JSON keys for the object.
inherited
-
noExtensions(
) → FhirStringBuilder -
Returns a copy with disallowExtensions set to
true.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
padLeft(
int width, [String padding = ' ']) → String -
Pads left side to
widthwithpadding.inherited -
padRight(
int width, [String padding = ' ']) → String -
Pads right side to
widthwithpadding.inherited -
prettyPrint(
) → String -
Converts the object to a pretty JSON string.
inherited
-
removeAnnotations(
Type type) → FhirBaseBuilder -
Annotations Methods
inherited
-
removeExtension(
String url) → void -
Method to remove an extension by url
inherited
-
replaceAll(
Pattern from, String replace) → String -
Replaces all occurrences of
fromwithreplace.inherited -
replaceAllMapped(
Pattern from, String replace(Match)) → String -
Replaces all occurrences with a mapped function.
inherited
-
replaceFirst(
Pattern from, String to, [int startIndex = 0]) → String -
Replaces the first occurrence of
fromwithto.inherited -
replaceFirstMapped(
Pattern from, String replace(Match), [int startIndex = 0]) → String -
Replaces the first occurrence with a mapped function.
inherited
-
replaceRange(
int start, int? end, String replacement) → String -
Replaces a range
start..endwithreplacement.inherited -
setChildByName(
String childName, dynamic child) → void -
Sets a property by name.
inherited
-
setChildrenByName(
Map< String, FhirBaseBuilder> children) → void -
Sets the properties of the object.
inherited
-
setProperty(
String name, dynamic value) → ElementBuilder -
Implementing the setProperty method
inherited
-
setUserData(
String name, dynamic value) → FhirBaseBuilder -
Sets user data for a given key.
inherited
-
split(
Pattern pattern) → List< String> -
Splits this string on
pattern.inherited -
splitMapJoin(
Pattern pattern, {String onMatch(Match)?, String onNonMatch(String)?}) → String -
Splits the string on
pattern, callingonMatch/onNonMatch.inherited -
startsWith(
Pattern pattern, [int index = 0]) → bool -
Checks if the string starts with
pattern.inherited -
substring(
int start, [int? end]) → String -
Substring of valueString from
startto optionalend.inherited -
toJson(
) → Map< String, dynamic> -
Serializes the instance to JSON with standardized keys
override
-
toJsonString(
) → String -
Converts the object to a JSON string.
inherited
-
toLowerCase(
) → String -
Converts the string to lower case.
inherited
-
toString(
) → String -
String representation
override
-
toUpperCase(
) → String -
Converts the string to upper case.
inherited
-
toYaml(
) → String -
Converts the object to a YAML string.
inherited
-
trim(
) → String -
Returns the valueString trimmed of whitespace.
inherited
-
trimLeft(
) → String -
Trims left side whitespace.
inherited
-
trimRight(
) → String -
Trims right side whitespace.
inherited
-
typeByElementName(
String elementName) → List< String> -
Retrieves the type of the object by element name.
inherited
-
withElement(
ElementBuilder? newElement) → DeviceMetricColorBuilder - Returns the enum value with an element attached
Operators
-
operator +(
String other) → String -
Concatenates this with
other.inherited -
operator ==(
Object other) → bool -
Equality operator override.
inherited
-
operator [](
int index) → String -
Returns the character at the specified
index.inherited
Static Properties
- black ↔ DeviceMetricColorBuilder
-
black
getter/setter pair
- blue ↔ DeviceMetricColorBuilder
-
blue
getter/setter pair
- cyan ↔ DeviceMetricColorBuilder
-
cyan
getter/setter pair
- elementOnly ↔ DeviceMetricColorBuilder
-
For instances where an Element is present but not value
getter/setter pair
- green ↔ DeviceMetricColorBuilder
-
green
getter/setter pair
- magenta ↔ DeviceMetricColorBuilder
-
magenta
getter/setter pair
- red ↔ DeviceMetricColorBuilder
-
red
getter/setter pair
-
values
↔ List<
DeviceMetricColorBuilder> -
List of all enum-like values
getter/setter pair
- white ↔ DeviceMetricColorBuilder
-
white
getter/setter pair
- yellow ↔ DeviceMetricColorBuilder
-
yellow
getter/setter pair