InteractionTriggerBuilderEnum enum
Actual enum for InteractionTrigger
Values
- read → const InteractionTriggerBuilderEnum
-
read
- vread → const InteractionTriggerBuilderEnum
-
vread
- update → const InteractionTriggerBuilderEnum
-
update
- patch → const InteractionTriggerBuilderEnum
-
patch
- delete → const InteractionTriggerBuilderEnum
-
delete
- history → const InteractionTriggerBuilderEnum
-
history
- historyInstance → const InteractionTriggerBuilderEnum
-
history-instance
- historyType → const InteractionTriggerBuilderEnum
-
history-type
- historySystem → const InteractionTriggerBuilderEnum
-
history-system
- create → const InteractionTriggerBuilderEnum
-
create
- search → const InteractionTriggerBuilderEnum
-
search
- searchType → const InteractionTriggerBuilderEnum
-
search-type
- searchSystem → const InteractionTriggerBuilderEnum
-
search-system
- capabilities → const InteractionTriggerBuilderEnum
-
capabilities
- transaction → const InteractionTriggerBuilderEnum
-
transaction
- batch → const InteractionTriggerBuilderEnum
-
batch
- operation → const InteractionTriggerBuilderEnum
-
operation
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String - Converts the enum value to a string.
-
toString(
) → String -
Returns the enum value as a string.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromJson(
dynamic json) → InteractionTriggerBuilderEnum? - Converts a string/JSON value to the corresponding enum value.
-
fromString(
String? value) → InteractionTriggerBuilderEnum? - Converts a string to the corresponding enum value.
Constants
-
values
→ const List<
InteractionTriggerBuilderEnum> - A constant List of the values in this enum, in order of their declaration.